#
# spec file for package gutenprint
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gutenprint
Url:            http://gutenprint.sourceforge.net
Version:        5.2.10
Release:        5.2
%define gutenprintmajor 5.2
BuildRequires:  cairo-devel
BuildRequires:  cups-ddk
BuildRequires:  cups-devel
BuildRequires:  gimp-devel
BuildRequires:  glib2-devel
BuildRequires:  gtk2-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
%if 0%{?suse_version} >= 1140
# The CUPS dyesub USB backend requires libusb-1.0 which is available since openSUSE 11.4.
# When libusb-1.0 is not available, the configure magic does not build the CUPS dyesub USB backend.
BuildRequires:  libusb-1_0-devel
%endif
BuildRequires:  pango-devel
BuildRequires:  python-cups
Summary:        Printer drivers for CUPS from the Gutenprint project
License:        GPL-2.0+
Group:          Hardware/Printing
# The "rastertogutenprint" filter requires CUPS and the "cups" output device in Ghostscript:
Requires:       cups >= 1.2.2
# Up to openSUSE 12.1 the package cups has "Requires: ghostscript_any" so that the above
# "Requires: cups" is sufficient to also get the "cups" output device in Ghostscript.
# Since openSUSE 12.2 the package cups has only "Recommends: ghostscript" to avoid
# an implicit build dependency cycle between the main-packages cups and ghostscript.
# Therefore after openSUSE 12.1 gutenprint needs an explicit "Requires: ghostscript"
# to ensure that the "cups" output device in Ghostscript is available:
%if 0%{?suse_version} > 1210
Requires:       ghostscript
%endif
# Install into this non-root directory (required when it is built as non-root user):
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# URL for Source0:
# http://downloads.sourceforge.net/project/gimp-print/gutenprint-5.2/5.2.10/gutenprint-5.2.10.tar.bz2
Source0:        gutenprint-%{version}.tar.bz2 
# Patch0...Patch9 is for patches from upstream:
# Patch10...Patch99 is for openSUSE patches which which are intended for upstream:
# Patch10 escputil-send_nulls-void.patch makes send_nulls a void function
# because nowhere is a return value of send_nulls used in escputil.c
# to fix a "no-return-in-nonvoid-function escputil.c:683" compiler error:

%description
The Gutenprint (formerly Gimp-Print) printer drivers for CUPS.
See the user's manual at /usr/share/gutenprint/doc/gutenprint-users-manual.pdf

%package devel
Summary:        Development environment for Gutenprint
Group:          Development/Libraries/C and C++
Requires:       cups >= 1.2.2
Requires:       ghostscript-library >= 7.05
Requires:       glibc-devel
Requires:       gtk2-devel
Requires:       gutenprint = %{version}

%description devel
The development environment for the Gutenprint printer drivers.
See the developers guide to Gutenprint at /usr/share/gutenprint/doc/gutenprint.pdf

%package gimpplugin
Summary:        Alternative GIMP print plug-in from the Gutenprint project
Group:          Hardware/Printing

%description -n gutenprint-gimpplugin
The enhanced Gutenprint GIMP print plug-in offers an alternative
with additional capabilities to the plugin supplied with GIMP.
See the user's manual at /usr/share/gutenprint/doc/gutenprint-users-manual.pdf

%prep
# Be quiet when unpacking:
%setup -q

%build
CFLAGS="$RPM_OPT_FLAGS -fstack-protector -fno-strict-aliasing -I/usr/include/gtk-2.0 -I/usr/include/cairo -I/usr/include/glib-2.0 -I%{_libdir}/gtk-2.0/include -I%{_libdir}/glib-2.0/include -I/usr/include/pango-1.0 -I/usr/include/atk-1.0 -I/usr/include/gimp-2.0" ./configure \
	--prefix=%{_prefix} \
	--mandir=%{_mandir} \
	--infodir=%{_infodir} \
	--sysconfdir=%{_sysconfdir} \
	--libdir=%{_libdir} \
	--disable-static \
	--enable-shared \
	--enable-cups-ppds \
	--enable-simplified-cups-ppds \
	--disable-translated-cups-ppds \
	--disable-libgutenprintui \
	--enable-libgutenprintui2 \
	--enable-samples \
	--enable-escputil \
	--with-pic=yes \
	--without-foomatic \
	--without-foomatic3 \
	--without-ghostscript \
	--without-gimp \
	--with-gimp2
make

%install
rm -rf $RPM_BUILD_ROOT/usr/share/cups/model
# Create required directories first:
install -d -m755 $RPM_BUILD_ROOT/bin
install -d -m755 $RPM_BUILD_ROOT/usr/share/cups/model
install -d -m755 $RPM_BUILD_ROOT/usr/lib/cups/filter
# Install Gutenprint:
make DESTDIR=$RPM_BUILD_ROOT install
# Work with upstream compliant CUPS 1.4 on all platforms
# which means to have a fixed "/usr/lib/cups/" directory
# on all platforms (see Novell/Suse Bugzilla bnc#575544):
for D in lib32 lib64
do for F in commandtocanon commandtoepson rastertogutenprint.%{gutenprintmajor}
   do if test -e $RPM_BUILD_ROOT/usr/$D/cups/filter/$F
      then mv -f $RPM_BUILD_ROOT/usr/$D/cups/filter/$F $RPM_BUILD_ROOT/usr/lib/cups/filter/$F
      fi
   done
   F="gutenprint.%{gutenprintmajor}"
   if test -e $RPM_BUILD_ROOT/usr/$D/cups/driver/$F
   then mv -f $RPM_BUILD_ROOT/usr/$D/cups/driver/$F $RPM_BUILD_ROOT/usr/lib/cups/driver/$F
   fi
done
# Disable the run-time PPD generator /usr/lib/cups/driver/gutenprint.5.2
# so that it is not executed by the cups-driverd (e.g. in response to a "lpinfo -m" request)
# to avoid duplicated PPDs because we create the PPDs during compile-time (via --enable-cups-ppds)
# and provide ready-made PPDs in /usr/share/cups/model/gutenprint/... in the RPM package
# see "Regarding CUPS PPD files" at https://bugzilla.novell.com/show_bug.cgi?id=514994#c9
chmod a-x $RPM_BUILD_ROOT/usr/lib/cups/driver/gutenprint.%{gutenprintmajor}
# Move the special testpattern generator away from the usual bin directory:
mv $RPM_BUILD_ROOT/%{_bindir}/testpattern $RPM_BUILD_ROOT/%{_libdir}/gutenprint/%{gutenprintmajor}
# Remove dispensable .po files (only the .mo files are needed on the end-users's system):
rm $RPM_BUILD_ROOT/usr/share/locale/*/gutenprint_*.po
%find_lang gutenprint

%post
/sbin/ldconfig
# update quietly Gutenprint PPD files in /etc/cups/ppd/ if such PPD files exist
# using the new PPD files under /usr/share/cups/model/gutenprint/ as templates
# see https://bugzilla.novell.com/show_bug.cgi?id=637455
/usr/sbin/cups-genppdupdate -q || /bin/true
# exit successfully in any case:
exit 0

%postun
/sbin/ldconfig
# exit successfully in any case:
exit 0

%files -f gutenprint.lang
%defattr(-,root,root)
%config /etc/cups/command.types
%{_bindir}/cups-calibrate
%{_bindir}/escputil
%{_sbindir}/cups-genppd*
%dir %{_libdir}/gutenprint
%dir %{_libdir}/gutenprint/%{gutenprintmajor}
%{_libdir}/gutenprint/%{gutenprintmajor}/*
%{_libdir}/libgutenprint*.so?*
%dir /usr/share/cups
/usr/share/cups/calibrate.ppm
%dir /usr/share/cups/model
%dir /usr/share/cups/model/gutenprint
%dir /usr/share/cups/model/gutenprint/%{gutenprintmajor}
%dir /usr/share/cups/model/gutenprint/%{gutenprintmajor}/C
/usr/share/cups/model/gutenprint/%{gutenprintmajor}/C/*
%dir /usr/lib/cups/driver
/usr/lib/cups/driver/gutenprint.%{gutenprintmajor}
/usr/lib/cups/filter/commandtocanon
/usr/lib/cups/filter/commandtoepson
/usr/lib/cups/filter/rastertogutenprint.%{gutenprintmajor}
%if 0%{?suse_version} >= 1140
/usr/lib/cups/backend/gutenprint52+usb
%dir /usr/share/cups/usb
/usr/share/cups/usb/net.sf.gimp-print.usb-quirks
%endif
%dir /usr/share/gutenprint
%dir /usr/share/gutenprint/%{gutenprintmajor}
/usr/share/gutenprint/%{gutenprintmajor}/*
%dir /usr/share/gutenprint/samples/
/usr/share/gutenprint/samples/*
%dir /usr/share/gutenprint/doc
%doc /usr/share/gutenprint/doc/*
%doc /usr/share/man/man?/*.gz

%files devel
%defattr(-,root,root)
%dir /usr/include/gutenprint
/usr/include/gutenprint/*
%dir /usr/include/gutenprintui2
/usr/include/gutenprintui2/*
%{_libdir}/libgutenprint*.la
%{_libdir}/pkgconfig/gutenprint*
%{_libdir}/libgutenprint*.so

%files gimpplugin
%defattr(-,root,root)
%dir %{_libdir}/gimp
%dir %{_libdir}/gimp/2.0
%dir %{_libdir}/gimp/2.0/plug-ins
%{_libdir}/gimp/2.0/plug-ins/*

%changelog
* Mon Jun  2 2014 jsmeix@suse.de
- Version upgrade to 5.2.10:
  * Added a unified CUPS backend 'gutenprint52+usb' that requires
    libusb 1.0 (or newer) to support selected dye sublimation
    printers. Support for all Canon SELPHY CP- and ES- printers
    has been improved considerably through that CUPS backend.
  * Added duplex support for the EPSON WorkForce 630, 635,
    and 645, and NX635.
  * Many new printers supported in this release.
  * Very many new printers supported experimentally.
  For details see the NEWS file.
- For openSUSE 11.4 or newer BuildRequires libusb-1_0-devel
  to build the 'gutenprint52+usb' backend. When libusb-1.0 is
  not installed, the configure magic does not build that backend.
  The installed /usr/share/cups/usb/net.sf.gimp-print.usb-quirks
  needs a current CUPS version (that supports usb quirks).
  Older CUPS versions would ignore gutenprint's usb quirks
  which means that the generic CUPS backend 'usb' reports
  in particular the dye sublimation printers that do not work
  with it but require the special 'gutenprint52+usb' backend.
* Wed Jan 23 2013 jsmeix@suse.de
- Do no longer send SIGHUP to cupsd in RPM post install script
  (which would let the cupsd recognize new and updated PPD files
  see the entry dated "Fri Sep 24 10:45:28 CEST 2010" below)
  because SIGHUP to cupsd makes active print jobs fail
  (see bnc#637455 starting at comment#3).
- Added explicit "Requires: ghostscript" if suse_version > 1210
  because since openSUSE 12.2 cups only "Recommends: ghostscript"
  (to avoid a build dependency cycle) so that gutenprint needs
  an explicit "Requires: ghostscript" for the "cups" device in
  Ghostscript that is required by "rastertogutenprint" (compare
  the entry dated "Thu Apr 28 17:20:03 CEST 2011" below).
* Wed Sep 26 2012 mmeister@suse.com
- Version upgrade to 5.2.9:
  Revert an inappropriate change to the internal library version
  number that was introduced in the 5.2.8 release.
- Version upgrade to 5.2.8:
  The Canon driver has been significantly overhauled. Its output
  and functionality may be significantly different from previous
  releases. Further work in future releases is expected.
  Several Canon PIXMA and SELPHY printers were removed, as they
  are not supported.
  Several Canon printers do not offer a grayscale printing mode.
  CD printing support for some Canon PIXMA printers was added.
  Added borderless functionality to most Canon printers
  (except S series and BJC series).
  Many new Canon printers are now EXPERIMENTAL supported.
  A few new Epson printers are now supported.
  For details see the NEWS file.
- escputil-send_nulls-void.patch is obsolete because its fixed
  in the sources.
- compile-fix.patch is obsolete because its fixed in the sources.
* Thu Oct 13 2011 aj@suse.de
- compile-fix.patch adds missing includes.
* Fri May 27 2011 vuntz@opensuse.org
- Add python-cups BuildRequires to have postscriptdriver() Provides
  for the drivers in gutenprint.
* Tue May 17 2011 jsmeix@suse.de
- Upgraded to version 5.2.7:
  This release features support for many additional Canon inkjets,
  some Epson inkjets, and some dye sublimation printers,
  greatly upgraded support for many Epson Stylus Pro printers,
  and numerous bug fixes.
  For details see the NEWS file.
- escputil-send_nulls-void.patch makes send_nulls a void function
  because nowhere is a return value of send_nulls used
  to fix a "no-return-in-nonvoid-function escputil.c:683" error.
* Thu Apr 28 2011 jsmeix@suse.de
- Removed the needless RPM requirement for pstoraster.
- Removed the duplicate RPM requirement for ghostscript-library
  because there is a RPM requirement for cups
  and cups requires ghostscript.
* Wed Dec 29 2010 jsmeix@suse.de
- Added missing directories for /usr/lib/gimp/2.0/plug-ins/*
  to the "gimpplugin" files section in the RPM spec file.
- Marked /usr/share/gutenprint/doc/* as "doc" in the RPM
  spec file (see Novell/openSUSE Bugzilla bnc#661350).
* Fri Sep 24 2010 jsmeix@suse.de
- Removed gutenprint-5.2.6-make_A4_DefaultPageSize.patch
  because it is useless because the DefaultPageSize in the PPD
  templates in /usr/share/cups/model/ does not matter because
  the cupsd sets the DefaultPageSize for PPDs in /etc/cups/ppd/
  by default according to the locale that the cupsd runs in or
  according to a DefaultPaperSize entry in /etc/cups/cupsd.conf.
- Run cups-genppdupdate in the RPM post install script to update
  Gutenprint PPD files in /etc/cups/ppd/ if such PPDs exist
  (see Novell/openSUSE Bugzilla bnc#637455).
* Thu Sep  2 2010 jsmeix@suse.de
- Disable the PPD generator /usr/lib/cups/driver/gutenprint.5.2
  to avoid duplicated PPDs because we provide ready-made PPDs
  in /usr/share/cups/model/gutenprint/... in the RPM package
  (see Novell/openSUSE Bugzilla bnc#514994 comment#9
  the section "Regarding CUPS PPD files").
* Wed Sep  1 2010 jsmeix@suse.de
- gutenprint-5.2.6-make_A4_DefaultPageSize.patch
  moves the paper definition for "A4" to the top of the list
  to make A4 the DefaultPageSize in the Gutenprint PPDs.
- Upgraded to version 5.2.6:
  This release offers additional support for Epson Stylus Pro
  printers, along with some changes for other Epson printers
  and support for additional Canon inkjets and PCL laser
  printers over 5.2.5. For details see the NEWS file.
- Upgraded to version 5.2.5:
  This release offers several fixes, new features, and support
  for new printers over 5.2.4. For details see the NEWS file.
* Fri Aug 13 2010 jsmeix@suse.de
- Split gutenprint from the cups-drivers package to have it as a
  stand-alone package (see Novell/openSUSE Bugzilla bnc#514994).
  The IJS driver /usr/bin/ijsgutenprint is no longer provided
  because it is not recommend if CUPS is used. Only the native
  CUPS driver is provided as recommend, see the README file.
